{% extends "layout.html" %}
{% block body %}

<p><b> Ready to install! Please review all changes.</b></p>

<p> This is the last chance to back out before committing to install, please ensure all the details are correct. </p>

<br>

{% for module in summary %}

<h3> <big> {{ summary[module]['heading'] }} </big> </h3>

<!-- {{ summary[module]['bleh'] }}
{{ summary[module]['settings'] }} -->
{{ summary[module]['text']|safe }}

<br /><br />

{% endfor %}

<br><br/>

<!-- <p>Config is: <code> {{ config }} </code></p> -->

</div>
</div>
</div>

{% endblock %}
