<!doctype html>
<html>
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <link href="/main/static/bulma.css" rel="stylesheet">
  <link href="/main/static/system-installer.css" rel="stylesheet">
  <link rel="shortcut icon" href="/main/static/icons/blippie.png" type="image/x-icon">
  <link rel="stylesheet" href="/main/static/fork-awesome.css">
  <script src="/main/static/htmx.min.js" crossorigin="anonymous"></script>
</head>
<body>

<div class="frame">
{% include "header.html" %}

<div class="applet">
{% block body %}
{% endblock %}
</div>

{% include "footer.html" %}

</div> <!-- class "frame" -->

</body>
</html>
