<div class="modal is-active">
  <div class="modal-background"></div>
  <div class="modal-content">

    <div style="background-color: #424242; padding: 15px; border-radius: 15px; boders: none; color: white;">
    <h1 class="is-size-4"> Disk: {{ disk }} </h1>

<p>

{% for pdisk in blockdevs["blockdevices"] if pdisk["name"] != "zram0" and "loop" not in pdisk["name"] and pdisk["name"] != "sr0" %}
{% if pdisk['name'] == disk %}

<p> Model: {{ pdisk['model'] }} </p>
<p> Revision: {{ pdisk['rev'] }} </p>
<p> Serial: {{ pdisk['serial'] }} </p>
<p> Link: {{ pdisk['id-link'] }} </p>
<p> Path: {{ pdisk['path'] }} </p>
<p> Label: {{ pdisk['label'] }} </p>
<p> Partition type: {{ pdisk['pttype'] }} </p>
<p> Interface: {{ pdisk['tran'] }} </p>
<p> Size: {{ pdisk['size'] }} </p>
<p> Flags: {{ pdisk['flags'] }} </p>
<p> UUID: {{ pdisk['uuid'] }} </p>
<p> Partitions: {{ pdisk['children']|count }} </p>

{% endif %}
{% endfor %}


</p>

    <div class="columns">
      <a href="/disks">
           <div class="column"><button class="button is-light">Cancel</button></div>
      </a>
      <a href="/disks"><div class="column"><button class="button is-link">Continue</button></div></a>
    </div>
  </div>
</div>
</div>
