{% extends "layout.html" %}
{% block body %}

<p><b>How would you like to install Debian?</b></p>

<br>

<div style="justify-content: center; margin-left: auto; margin-right: auto; width: 100%; display: flex;i align-items: center;">

<a href="">
<div style="width: 200px; float: left; padding: 10px; color: white;">
<img width="130px;" src="/disks/static/img/install_alongside.png"><br>
Install next to existing partition
</div>
</a>

<a href="/disks/choose_partition_erase">
<div style="width: 200px; float: left; padding: 10px; color: white;">
<img width="130px;" src="/disks/static/img/erase_partition.png"><br>
Replace a partition
</div>
</a>

<a href="/disks/choose_disk_erase">
<div style="width: 200px; float: left; padding: 10px; color: white;">
<img width="130px;" src="/disks/static/img/erase_disk.png"><br>
Erase entire disk
</div>
</a>

<a href="/disks/advanced">
<div style="width: 200px; float: left; padding: 10px; color: white;">
<img width="130px;" src="/disks/static/img/advanced_partitioning.png"><br>
Advanced partitioning
</div>
</a>

<!--
    <a href="">
<div style="width: 200px; float: left; padding: 10px; color: white;">
<img width="130px;" src="/disks/static/img/preconfigured_partitioning.png"><br>
Preconfigured Partitioning
</div>
</a>
-->
</div>

<br>

<div style="clear:both;">
<p> <b>The following devices have been detected:</b>

<br><br>

<ul>
{% for disk in blockdevs["blockdevices"] if disk["name"] != "zram0" and "loop" not in disk["name"] and disk["name"] != "sr0" %}
<li><b>{{ disk['name'] }}</b> - {{ disk['tran'] }} disk of {{ disk['size'] }} with a {{ disk['pttype'] }} partition table, containing {{ disk['children']|count }} partitions.</li>
{% endfor %}
</ul>

{% endblock %}

</div>
