html {
    /* Overwrite the white that is set by bulma.css */
    background: transparent;
}

body {
    display: flex;
    font-family: Sans; Roboto; Lato; Noto Sans;
    color: white;
    overflow: hidden;
    min-width: 1050px;
    min-height: 600px;
    user-select: none;
}

html, body {margin: 0; height: 100%; overflow: hidden;}

.frame {
    border-radius: 10px;
    background-color: #404040;
    padding: 15px 15px 15px 15px;
    width: 100%;
    min-height: 600px;
    position: absolute;
    top: 0px;
    bottom: 0px;
    user-select: none;
}

.applet a:link a:hover a:active {
     color: yellow;
}

.applet::-webkit-scrollbar {
     display: none;
}


.applet {
    width: 100%;
    height: 512px;
    overflow-y: scroll;
    overflow-x: hidden;
    overflow: -moz-scrollbars-none;
}

.radio:hover {
    color: #f1f1f1;
}

.pywebview-drag-region {
    width: 100%;
    height: 85px;
}

.progress {
    left: 0;
    right: 0;
    border-radius: 0px;
    position: absolute;
    background-color: #363636;
    height: 80px;
    bottom: 0px;
    border-radius: 0 0 10px 10px;
}

.progress-bar {
    margin-left: 20px;
    margin-top: 20px;
    max-width: 96%;
    float: left;
    border-radius: 3px;
    height: 8px;
    background-color: #a0ff98;
    -webkit-box-shadow: inset 0 -1px 0 rgba(0,0,0,.15);
    -webkit-transition: width .6s ease;
    -o-transition: width .6s ease;
    transition: width .6s ease;
    margin-bottom: 10px;
    transition: width 2s;
}

.install-label {
    clear: left;
    float: none;
    display: block;
}
