html {
    /* Overwrite the white that is set by bulma.css */
body {
    display: flex;
    font-family: Noto Sans;
    color: white;
    overflow: hidden;
    min-width: 1050px;
    min-height: 600px;
}

.frame {
    border-radius: 10px;
    background-color: #0f1933;
    padding: 15px 15px 15px 15px;
    width: 100%;
    min-height: 600px;
    position: absolute;
    top: 0px;
    bottom: 0px;
}

.applet a:link a:hover a:active {
     color: yellow;
}

.applet {
    width: 100%;
    height: 470px;
    bottom: 0px;
    overflow-y: scroll;
    overflow-x: hidden;
}

.radio:hover {
    color: #f1f1f1;
}
