from flask import Blueprint

bp = Blueprint('users', __name__,
               template_folder='',
               static_folder='static',
               static_url_path='/users/static')


from yasi_applets.users import routes

