from flask import Blueprint

bp = Blueprint('welcome', __name__,
               template_folder='',
               static_folder='static',
               static_url_path='/welcome/static')

from yasi_applets.welcome import routes
